@@ -68,6 +68,35 @@ public:
     Uri & operator=(const Uri & orig);
     virtual ~Uri();
 
+    /// append a query parameter to the uri
+    /// @param key : parameter key, not escaped
+    /// @param value : parameter value, not escaped
+    void addQueryParam(const std::string & key, const std::string & value);
+
+    /// append a fragment parameter to the uri
+    /// @param key : key
+    /// @param value : value
+    void addFragmentParam(const std::string & key, const std::string & value);
+
+    /// append a path segment to the uri
+    /// @param seg : the segment to add
+    void addPathSegment(const std::string & seg);
+
+    /// ensure that the path ends with a trailing slash
+    void ensureTrailingSlash();
+
+    /// remove the path's trailing slash, if it exists
+    void removeTrailingSlash();
+
+    /// check if the given query parameter exists
+    bool queryParamExists(const std::string &param) const;
+
+    /// check if the given fragment parameter exists
+    bool fragmentParamExists(const std::string &param) const;
+
+    /// get the value of a fragment parameter
+    const std::string getFragmentParam(const std::string &param) const;
+
     /// get a string representation of the full uri
     /// @return return the path or an empty string if error
     const std::string & getString() const;
@@ -88,6 +117,15 @@ public:
     /// @return return the path of the Uri or an empty string if error
     const std::string & getPath()const;
 
+    // set the path part of the Uri
+    void setPath(const std::string & path);
+
+    // change the protocol of the Uri
+    void setProtocol(const std::string & protocol);
+
+    // change the protocol to either http or https, whichever is appropriate
+    void httpizeProtocol();
+
     /// gextract user information from the URI
     /// @return return the path of the Uri or an empty string if error
     const std::string & getUserInfo() const;
@@ -96,10 +134,18 @@ public:
     /// @return return a path + query arguments concatenation or an empty string if error
     const std::string & getPathAndQuery() const;
 
+    /// get the fragment part of the uri
+    /// @return return the fragment part or an empty string if it does not exist
+    const std::string & getFragment() const;
+
     /// get the query argument part of the uri
     /// @return return the query path string or an empty string if not exist or if error
     const std::string & getQuery() const;
 
+    // get the query argument part of the uri as a vector
+    // @return return a vector with all query parameters
+    ParamVec getQueryVec() const;
+
     /// Status of the Uri
     /// see StatusCode::Code
     /// @return StatusCode::OK if success or StatusCode::UriParsingError if error
@@ -134,6 +180,13 @@ public:
     ///
     static std::string unescapeString(const std::string & str);
 
+    ///
+    /// \brief Escape query parameter
+    /// \param str to escape
+    /// \return encoded string
+
+    static std::string queryParamEscape(const std::string & str);
+
     ///
     /// \brief create a new Uri from URI and a relative associated path
     /// \param uri original URI
