@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -95,13 +95,16 @@ public:
 
     // make collection
     virtual void makeCollection(IOChainContext & iocontext);
-    
+
     // move/rename resource
     virtual void move(IOChainContext & iocontext, const std::string & target_url);
 
     // get statInfo
     virtual StatInfo & statInfo(IOChainContext & iocontext, StatInfo & st_info);
 
+    // get quota info
+    virtual QuotaInfo & quotaInfo(IOChainContext & iocontext, QuotaInfo & info);
+
     // listing
     // return false if end of directory is reached
     virtual bool nextSubItem(IOChainContext & iocontext, std::string & entry_name, StatInfo & info);
