@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -172,6 +172,10 @@ MultirangeResult HttpIOVecOps::performMultirange(IOChainContext & iocontext,
                         }
                         break;
                     }
+                    else if(retcode == 416) {
+                      ret = 0;
+                      DavixError::clearError(&tmp_err);
+                    }
                     else {
                         httpcodeToDavixError(req.getRequestCode(),davix_scope_http_request(),", ", &tmp_err);
                         ret = -1;
@@ -180,10 +184,10 @@ MultirangeResult HttpIOVecOps::performMultirange(IOChainContext & iocontext,
 
                     p_diff += it->first;
                     ret += tmp_ret;
+                } else {
+                   ret = -1;
+                   break;
                 }
-            } else {
-                ret = -1;
-                break;
             }
         }
     }
@@ -326,29 +330,40 @@ dav_ssize_t HttpIOVecOps::preadVec(IOChainContext & iocontext, const DavIOVecInp
     if(count_vec ==0)
         return 0;
 
-    IntervalTree<ElemChunk> tree = buildIntervalTree(input_vec, output_vec, count_vec);
-    SortedRanges sorted = partialMerging(tree, 200);
+    for(dav_size_t i = 0; i < count_vec; i++) {
+      output_vec[i].diov_size = 0;
+    }
+
+    // size of merge window
+    dav_size_t mergewindow = 2000;
+    if(iocontext._uri.fragmentParamExists("mergewindow")) {
+        mergewindow = atoi(iocontext._uri.getFragmentParam("mergewindow").c_str());
+        DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_CHAIN, "Setting mergewindow to {}", mergewindow);
+    }
 
     // number of parallel connections in case of a simulation
-    uint nconnections = 10;
+    uint nconnections = 3;
     if(iocontext._uri.fragmentParamExists("nconnections")) {
         nconnections = atoi(iocontext._uri.getFragmentParam("nconnections").c_str());
         DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_CHAIN, "Setting number of desired parallel connections to {}", nconnections);
     }
 
+    IntervalTree<ElemChunk> tree = buildIntervalTree(input_vec, output_vec, count_vec);
+
     // a lot of servers do not support multirange... should we even try?
     if(count_vec == 1 || iocontext._uri.getFragmentParam("multirange") == "false") {
-        sorted = partialMerging(tree, 2000);
+        SortedRanges sorted = partialMerging(tree, mergewindow);
         return simulateMultirange(iocontext, tree, sorted, nconnections);
     }
 
+    SortedRanges sorted = partialMerging(tree, mergewindow);
     MultirangeResult res = performMultirange(iocontext, tree, sorted);
     if(res.res == MultirangeResult::SUCCESS || res.res == MultirangeResult::SUCCESS_BUT_NO_MULTIRANGE) {
         return res.size_bytes;
     }
     else {
         DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_CHAIN, "Multi-range request has failed, attempting to recover by using multiple single-range requests");
-        sorted = partialMerging(tree, 1000);
+        sorted = partialMerging(tree, mergewindow);
         return simulateMultirange(iocontext, tree, sorted, nconnections);
     }
 }
@@ -497,7 +512,7 @@ static void copyBytes(const char *source, dav_off_t offset, dav_size_t size, Ele
             source+(common_offset-offset), intersect_dist);
 
     chunk._ou->diov_buffer = chunk._in->diov_buffer;
-    chunk._ou->diov_size = chunkSize;
+    chunk._ou->diov_size += intersect_dist;
 }
 
 // find all matching chunks in tree and fill them
@@ -518,7 +533,7 @@ dav_ssize_t copyChunk(HttpRequest & req, const IntervalTree<ElemChunk> &tree, da
                       DavixError** err){
     DavixError* tmp_err=NULL;
     dav_ssize_t ret;
-    DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_CHAIN, "Davix::parseMultipartRequest::copyChunk copy {} bytes with offset {}", offset, size);
+    DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_CHAIN, "Davix::parseMultipartRequest::copyChunk copy {} bytes with offset {}", size, offset);
 
     std::vector<char> buffer;
     buffer.resize(size+1);
