@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -185,13 +185,16 @@ dav_ssize_t HttpIO::pread(IOChainContext & iocontext, void *buf, dav_size_t coun
         if(req.beginRequest(&tmp_err) ==0){
             if(req.getRequestCode() == 416 ){ // out of file, end of file
                 ret = 0; // end of file
+                DavixError::clearError(&tmp_err);
             }else{
                 if(req.getRequestCode() == 206 ){ // partial request supported, just read !
                     ret = read_segment_request(&req, buf, count, &tmp_err);
 
                     // clean remaining content
-                    char buffer[255];
-                    while( req.readBlock(buffer, 255, NULL) > 0);
+                    if(!tmp_err) {
+                        char buffer[255];
+                        while( req.readBlock(buffer, 255, NULL) > 0);
+                    }
 
                 }else if( req.getRequestCode() == 200){ // full request content -> skip useless content
                     ret = read_truncated_segment_request(&req, buf, count, offset, &tmp_err);
@@ -504,9 +507,12 @@ dav_ssize_t HttpIOBuffer::write(IOChainContext & iocontext, const void *buf, dav
     dav_ssize_t ret =-1;
     dav_size_t write_len = count;
 
+    if(!_opened) {
+        throw DavixException(davix_scope_io_buff(), StatusCode::SystemError, "Impossible to write, descriptor has not been opened");
+    }
 
-    if(_local.get() == NULL || !_opened){
-        throw DavixException(davix_scope_io_buff(), StatusCode::SystemError, "Impossible to write, I/O Error");
+    if(_local.get() == NULL) {
+        throw DavixException(davix_scope_io_buff(), StatusCode::SystemError, "Impossible to write, no buffer. (file was opened only for reading?)");
     }
 
     do{
