@@ -145,7 +145,7 @@ static int populateTaskQueue(Context& c, const Tool::OptParams & opts, std::stri
     if(tmp_err){
         Tool::errorPrint(&tmp_err);
         cerr << endl << "Error occured during listing  " << dirQueue.front().first << " Number of entries processed in current directory: " << entry_counter << ". Continuing..."<< endl;
-        cerr << endl << "Last succesful entry is " << last_success_entry << endl;
+        cerr << endl << "Last successful entry is " << last_success_entry << endl;
     }
 
     entry_counter = 0;
