@@ -1,6 +1,6 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) CERN 2013  
+ * Copyright (C) CERN 2013
  * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@
 #include <davix_internal.hpp>
 #include "davix_tool_params.hpp"
 #include "davix_tool_util.hpp"
+#include "davix_config_parser.hpp"
 #include <getopt.h>
 #include <string_utils/stringutils.hpp>
 #include <utils/davix_logger.hpp>
@@ -58,6 +59,7 @@ const std::string scope_params = "Davix::Tools::Params";
 #define S3_ALTERNATE        1021
 #define AZURE_KEY           1022
 #define S3_TOKEN            1023
+#define NO_100_CONTINUE     1024
 
 // LONG OPTS
 
@@ -102,6 +104,9 @@ const std::string scope_params = "Davix::Tools::Params";
 {"no-cap", required_argument, 0, DISABLE_LISTING_CAP}, \
 {"long-list", no_argument, 0,  'l' }
 
+#define PUT_LONG_OPTIONS \
+{"no-100-continue", no_argument, 0,  NO_100_CONTINUE }
+
 #define COPY_LONG_OPTIONS \
 {"copy-mode", required_argument, 0,  THIRD_PT_COPY_MODE }
 
@@ -115,9 +120,11 @@ OptParams::OptParams() :
     help_msg(),
     cred_path(),
     priv_key(),
+    cred_pass(),
     output_file_path(),
     input_file_path(),
     userlogpasswd(),
+    userlogpasswd_through_cmdline(false),
     req_content(),
     aws_auth(),
     aws_region(),
@@ -201,6 +208,11 @@ static struct timespec parse_timeout(const std::string & opt, char** argv){
     return timelapse;
 }
 
+void parse_davix_config(OptParams &p, std::string url) {
+    if(davix_config_apply("~/.davixrc", p, url)) return;
+    if(davix_config_apply("~/.netrc", p, url)) return;
+}
+
 int parse_davix_options_generic(const std::string &opt_filter,
                                 const struct option* long_options,
                                 int argc, char** argv, OptParams & p, DavixError** err){
@@ -230,7 +242,7 @@ int parse_davix_options_generic(const std::string &opt_filter,
             case S3_LISTING_MODE:
                 {
                     if(std::string(optarg).compare("flat")==0)
-                        p.params.setS3ListingMode(S3ListingMode::Flat); 
+                        p.params.setS3ListingMode(S3ListingMode::Flat);
                     else if(std::string(optarg).compare("hierarchical")==0)
                         p.params.setS3ListingMode(S3ListingMode::Hierarchical);
                     else if(std::string(optarg).compare("semi")==0)
@@ -245,6 +257,7 @@ int parse_davix_options_generic(const std::string &opt_filter,
                 break;
             case USER_LOGIN:
                 p.userlogpasswd.first = optarg;
+                p.userlogpasswd_through_cmdline = true;
                 strncpy(optarg, "", strlen(optarg));
                 break;
             case X509_PRIVATE_KEY:
@@ -252,6 +265,7 @@ int parse_davix_options_generic(const std::string &opt_filter,
                 break;
             case USER_PASSWORD:
                 p.userlogpasswd.second = optarg;
+                p.userlogpasswd_through_cmdline = true;
                 strncpy(optarg, "", strlen(optarg));
                 break;
             case DATA_CONTENT:
@@ -329,18 +343,18 @@ int parse_davix_options_generic(const std::string &opt_filter,
              }
             case HAS_INPUT_FILE:{
                 p.has_input_file = true;
-                p.input_file_path = optarg; 
+                p.input_file_path = optarg;
                 }
                 break;
             case THIRD_PT_COPY_MODE:{
                 if(std::string(optarg).compare("pull")==0)
-                    p.params.setCopyMode(CopyMode::Pull); 
+                    p.params.setCopyMode(CopyMode::Pull);
                 else if(std::string(optarg).compare("push")==0)
                     p.params.setCopyMode(CopyMode::Push);
-                break;                
+                break;
                 }
             case DISABLE_LISTING_CAP:{
-                p.no_cap = true; 
+                p.no_cap = true;
                 break;
                 }
             case 'r':{
@@ -352,6 +366,10 @@ int parse_davix_options_generic(const std::string &opt_filter,
                 p.s3_delete_per_request = (atoi(optarg));
                 break;
                 }
+            case NO_100_CONTINUE:{
+                p.params.set100ContinueSupport(false);
+                break;
+            }
             case '?':
                 std::cout <<  p.help_msg;
                 exit(1);
@@ -386,9 +404,14 @@ int parse_davix_options(int argc, char** argv, OptParams & p, DavixError** err){
         {0,         0,                 0,  0 }
      };
 
-    return parse_davix_options_generic(arg_tool_main, long_options,
+    if( parse_davix_options_generic(arg_tool_main, long_options,
                                        argc, argv,
-                                       p, err);
+                                       p, err) < 0) {
+        return -1;
+    }
+
+    parse_davix_config(p, p.vec_arg[0]);
+    return 0;
 }
 
 
@@ -408,6 +431,7 @@ int parse_davix_ls_options(int argc, char** argv, OptParams & p, DavixError** er
         option_abort(argv);
         return -1;
     }
+    parse_davix_config(p, p.vec_arg[0]);
     return 0;
 }
 
@@ -431,6 +455,7 @@ int parse_davix_get_options(int argc, char** argv, OptParams & p, DavixError** e
     if(p.vec_arg.size() == 2){
         p.output_file_path = p.vec_arg[1];
     }
+    parse_davix_config(p, p.vec_arg[0]);
     return 0;
 }
 
@@ -439,11 +464,10 @@ int parse_davix_put_options(int argc, char** argv, OptParams & p, DavixError** e
     const struct option long_options[] = {
         COMMON_LONG_OPTIONS,
         SECURITY_LONG_OPTIONS,
+        PUT_LONG_OPTIONS,
         {0,         0,                 0,  0 }
      };
 
-
-
     if( parse_davix_options_generic(arg_tool_main,
                                     long_options,
                                     argc,
@@ -455,6 +479,7 @@ int parse_davix_put_options(int argc, char** argv, OptParams & p, DavixError** e
         return -1;
     }
     p.input_file_path = p.vec_arg[0];
+    parse_davix_config(p, p.vec_arg[1]);
     return 0;
 }
 
@@ -468,9 +493,14 @@ int parse_davix_copy_options(int argc, char** argv, OptParams & p, DavixError**
         {0,         0,                 0,  0 }
      };
 
-    return parse_davix_options_generic(arg_tool_main, long_options,
+    if(parse_davix_options_generic(arg_tool_main, long_options,
                                        argc, argv,
-                                       p, err);
+                                       p, err) < 0) {
+        return -1;
+    }
+
+    parse_davix_config(p, p.vec_arg[0]);
+    return 0;
 }
 
 int parse_davix_rm_options(int argc, char** argv, OptParams & p, DavixError** err){
@@ -482,15 +512,20 @@ int parse_davix_rm_options(int argc, char** argv, OptParams & p, DavixError** er
         {0,         0,                 0,  0 }
      };
 
-    return parse_davix_options_generic(arg_tool_main, long_options,
+    if( parse_davix_options_generic(arg_tool_main, long_options,
                                        argc, argv,
-                                       p, err);
+                                       p, err) < 0) {
+        return -1;
+    }
+
+    parse_davix_config(p, p.vec_arg[0]);
+    return 0;
 }
 
 std::string get_common_options(){
            return  "  Common Options:\n"
             "\t--conn-timeout TIME:      Connection timeout in seconds. default: 30\n"
-            "\t--retry NUMBER:           Number of retry attempt in case of an operation failure. default: 10\n"
+            "\t--retry NUMBER:           Number of retry attempts in case of an operation failure. default: 3\n"
             "\t--retry-delay TIME:       Number of seconds to wait between retry attempts. default: 0\n"
             "\t--debug:                  Debug mode\n"
             "\t--header, -H:             Add a header field to the request\n"
