@@ -21,6 +21,7 @@
 
 #include <davix_internal.hpp>
 #include <utils/davix_uri.hpp>
+#include <boost/algorithm/string/replace.hpp>
 
 
 namespace Davix {
@@ -44,6 +45,7 @@ struct UriPrivate{
         path(),
         host(),
         query(),
+        fragment(),
         port(0),
         _uri_string(),
         query_and_path(NULL){}
@@ -55,6 +57,7 @@ struct UriPrivate{
         path(orig.path),
         host(orig.host),
         query(orig.query),
+        fragment(orig.fragment),
         port(orig.port),
         _uri_string(orig._uri_string),
         query_and_path(NULL){ }
@@ -74,6 +77,44 @@ struct UriPrivate{
         }
     }
 
+    void addParam(const std::string & key, const std::string & value, std::string & target) {
+        if(target.size() == 0) {
+            target = key + "=" + value;
+        }
+        else {
+            target += "&" + key + "=" + value;
+        }
+        _update_string();
+    }
+
+    void addQueryParam(const std::string & key, const std::string & value) {
+        addParam(key, value, query);
+    }
+
+    void addFragmentParam(const std::string & key, const std::string & value) {
+        addParam(key, value, fragment);
+    }
+
+    void addPathSegment(const std::string &seg) {
+        ensureTrailingSlash();
+        path += seg;
+        _update_string();
+    }
+
+    void ensureTrailingSlash() {
+        if(path.size() == 0 || path[path.size() - 1] != '/') {
+            path += "/";
+            _update_string();
+        }
+    }
+
+    void removeTrailingSlash() {
+        if(path.size() != 0 && path[path.size() - 1] == '/') {
+            path.erase(path.size()-1, 1);
+            _update_string();
+        }
+    }
+
     void clear(){
         proto.clear();
         userinfo.clear();
@@ -84,6 +125,19 @@ struct UriPrivate{
         port = 0;
     }
 
+    void _update_string() {
+        std::ostringstream ss;
+        ss << proto << "://";
+        if(userinfo.size() > 0) ss << "@" << userinfo;
+        ss << host;
+        if(port != 0) ss << ":" << port;
+        ss << path;
+        if(query.size() > 0) ss << "?" << query;
+        if(fragment.size() > 0) ss << "#" << fragment;
+
+        _uri_string = ss.str();
+    }
+
     StatusCode::Code code;
     std::string proto, userinfo, path, host, query, fragment;
     unsigned int port;
@@ -106,6 +160,36 @@ Uri::Uri(const Uri & uri) :
     d_ptr(new UriPrivate(*(uri.d_ptr))){
 }
 
+void Uri::addQueryParam(const std::string & key, const std::string & value) {
+    d_ptr->addQueryParam(Uri::queryParamEscape(key), Uri::queryParamEscape(value));
+}
+
+
+void Uri::addFragmentParam(const std::string & key, const std::string & value) {
+    d_ptr->addFragmentParam(key, value);
+}
+
+void Uri::addPathSegment(const std::string &seg) {
+    d_ptr->addPathSegment(seg);
+}
+
+void Uri::ensureTrailingSlash() {
+    d_ptr->ensureTrailingSlash();
+}
+
+void Uri::removeTrailingSlash() {
+    d_ptr->removeTrailingSlash();
+}
+
+bool Uri::queryParamExists(const std::string &key) const {
+    ParamVec queryVec = this->getQueryVec();
+    for(ParamVec::iterator it = queryVec.begin(); it != queryVec.end(); it++) {
+        if(it->first == key)
+            return true;
+    }
+    return false;
+}
+
 Uri::~Uri(){
     delete d_ptr;
 }
@@ -136,6 +220,25 @@ const std::string & Uri::getPath() const {
     return d_ptr->path;
 }
 
+void Uri::setPath(const std::string & path) {
+    d_ptr->path = path;
+    d_ptr->_update_string();
+}
+
+void Uri::setProtocol(const std::string & protocol) {
+    d_ptr->proto = protocol;
+    d_ptr->_update_string();
+}
+
+void Uri::httpizeProtocol() {
+    if(d_ptr->proto == "s3" || d_ptr->proto == "dav") {
+        setProtocol("http");
+    }
+    if(d_ptr->proto == "s3s" || d_ptr->proto == "davs") {
+        setProtocol("https");
+    }
+}
+
 const std::string & Uri::getPathAndQuery() const {
     if(d_ptr->query_and_path.get() == NULL){
         if(d_ptr->query.size() > 0){
@@ -147,6 +250,56 @@ const std::string & Uri::getPathAndQuery() const {
     return *(d_ptr->query_and_path);
 }
 
+static ParamVec splitParams(const std::string &str) {
+    ParamVec params;
+    const std::string paramSeparator = "&";
+    const std::string pairSeparator = "=";
+
+    std::string::size_type curr = 0;
+    while(curr < str.length()) {
+        std::string::size_type next = str.find(paramSeparator, curr);
+        if(next == std::string::npos) next = str.length();
+        std::string param = str.substr(curr, next-curr);
+
+        // separate the two parts between '='
+        std::string::size_type eq = param.find(pairSeparator);
+        if(eq == std::string::npos) {
+            params.push_back(ParamLine(param, ""));
+        } else {
+            params.push_back(ParamLine(param.substr(0, eq), param.substr(eq+1, param.length())));
+        }
+
+        curr = next+1;
+    }
+    return params;
+}
+
+const std::string & Uri::getFragment() const {
+    return d_ptr->fragment;
+}
+
+bool Uri::fragmentParamExists(const std::string &param) const {
+    ParamVec fragmentVec = splitParams(getFragment());
+    for(ParamVec::iterator it = fragmentVec.begin(); it != fragmentVec.end(); it++) {
+        if(it->first == param)
+            return true;
+    }
+    return false;
+}
+
+const std::string Uri::getFragmentParam(const std::string &param) const {
+    ParamVec fragmentVec = splitParams(getFragment());
+    for(ParamVec::iterator it = fragmentVec.begin(); it != fragmentVec.end(); it++) {
+        if(it->first == param)
+            return it->second;
+    }
+    return "";
+}
+
+ParamVec Uri::getQueryVec() const {
+    return splitParams(getQuery());
+}
+
 const std::string & Uri::getQuery() const{
     return d_ptr->query;
 }
@@ -185,6 +338,10 @@ std::string Uri::unescapeString(const std::string & str){
     return davix_path_unescape(str);
 }
 
+std::string Uri::queryParamEscape(const std::string & str) {
+    std::string tmp = escapeString(str);
+    return boost::replace_all_copy(tmp, "/", "%2F");
+}
 
 // FIX IT : does not manage properly ../
 Uri Uri::fromRelativePath(const Uri &uri, const std::string &relPath){
@@ -530,7 +687,7 @@ std::string davix_path_escape(const std::string & str)
     for (pnt = (const unsigned char *)path; *pnt != '\0'; pnt++) {
     if (path_escape_ch(*pnt)) {
         /* Escape it - %<hex><hex> */
-        sprintf(p, "%%%02x", (unsigned char) *pnt);
+        sprintf(p, "%%%02X", (unsigned char) *pnt);
         p += 3;
     } else {
         *p++ = *pnt;
